@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -19,10 +17,12 @@
 
 """ Utilities to load parameters and options from a configuration file. """
 
+from pathlib import Path
+
 import click
 import tomlkit
-from pathlib import Path
-from . import logger, CLI_NAME
+
+from . import CLI_NAME, logger
 
 
 def config_structure():
