@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -234,5 +232,5 @@ class Gem(PackageManager):
                 for the /Library/Ruby/Gems/2.6.0 directory.
             Clean up complete
         """
-        super(Gem, self).cleanup()
+        super().cleanup()
         self.run_cli("cleanup", self.global_args)
