@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -145,7 +143,7 @@ class CLISubCommandTests:
     @pytest.mark.parametrize("opt_stats", ["--stats", "--no-stats", None])
     @pytest.mark.parametrize("opt_timer", ["--time", "--no-time", None])
     def test_options(self, invoke, subcmd, opt_stats, opt_timer):
-        """ Test the result on all combinations of optional options. """
+        """Test the result on all combinations of optional options."""
         result = invoke(opt_stats, opt_timer, subcmd)
         assert result.exit_code == 0
 
@@ -171,38 +169,35 @@ class CLISubCommandTests:
             # the CLI. Roughly sorted from most specific to more forgiving.
             signals = [
                 # Common "not found" warning message.
-                "warning: Skip unavailable {} manager.".format(mid) in result.stderr,
+                f"warning: Skip unavailable {mid} manager." in result.stderr,
                 # Common "not implemented" optional command warning message.
                 bool(
                     re.search(
-                        r"warning: (Sync|Cleanup) not implemented for {}.".format(mid),
+                        fr"warning: (Sync|Cleanup|Search) not implemented for {mid}.",
                         result.stderr,
                     )
                 ),
                 # Stats line at the end of output.
-                "{}: ".format(mid) in result.stdout.splitlines()[-1]
-                if result.stdout
-                else "",
+                f"{mid}: " in result.stdout.splitlines()[-1] if result.stdout else "",
                 # Match output of managers command.
                 bool(
                     re.search(
-                        r"\s+│\s+{}\s+│\s+(✓|✘).+│\s+(✓|✘)".format(mid),
+                        fr"\s+│\s+{mid}\s+│\s+(✓|✘).+│\s+(✓|✘)",
                         strip_ansi(result.stdout),
                     )
                 ),
                 # Sync command.
-                "Sync {} package info...".format(mid) in result.stderr,
+                f"Sync {mid} package info..." in result.stderr,
                 # Upgrade command.
-                "Updating all outdated packages from {}...".format(mid)
-                in result.stderr,
+                f"Updating all outdated packages from {mid}..." in result.stderr,
                 # Cleanup command.
-                "Cleanup {}...".format(mid) in result.stderr,
+                f"Cleanup {mid}..." in result.stderr,
                 # Log message for backup command.
-                "Dumping packages from {}...".format(mid) in result.stderr,
+                f"Dumping packages from {mid}..." in result.stderr,
                 # Restoring message.
-                "Restore {} packages...".format(mid) in result.stderr,
+                f"Restore {mid} packages..." in result.stderr,
                 # Warning message for restore command.
-                "warning: No [{}] section found.".format(mid) in result.stderr,
+                f"warning: No [{mid}] section found." in result.stderr,
             ]
 
             if True in signals:
@@ -223,7 +218,7 @@ class CLISubCommandTests:
         assert selector in result.stderr
 
     def test_default_all_managers(self, invoke, subcmd):
-        """ Test all available managers are selected by default. """
+        """Test all available managers are selected by default."""
         result = invoke(subcmd)
         assert result.exit_code == 0
         self.check_manager_selection(result)
@@ -317,7 +312,7 @@ class CLITableTests:
         assert RENDERING_MODES == set(self.expected_renderings.keys())
 
     def test_default_table_rendering(self, invoke, subcmd):
-        """ Check default rendering is fancy_grid. """
+        """Check default rendering is fancy_grid."""
         result = invoke(subcmd)
         assert result.exit_code == 0
 
